OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Təqvim",
    "Cheers!" : "Şərəfə!",
    "Today" : "Bu gün",
    "Day" : "Gün",
    "Week" : "Həftə",
    "Month" : "Ay",
    "Download" : "Yüklə",
    "Delete" : "Sil",
    "Share link" : "Linki yayımla",
    "can edit" : "dəyişmək olar",
    "New calendar" : "Yeni təqvim",
    "Cancel" : "Dayandır",
    "Automatic" : "Avtomatik",
    "Email" : "Email",
    "from" : "ondan",
    "to" : "doğru",
    "never" : "heç vaxt",
    "Repeat" : "Təkrar",
    "Monday" : "Bazar ertəsi",
    "More" : "Daha da",
    "Save" : "Saxla",
    "Update" : "Yenilənmə",
    "Personal" : "Şəxsi",
    "Details" : "Detallar",
    "Attendees" : "İştirakçılar",
    "Activity" : "Fəallıq",
    "Close" : "Bağla",
    "Daily" : "Günlük",
    "Weekly" : "Həftəlik",
    "Location" : "Yerləşdiyiniz ünvan",
    "Description" : "Açıqlanma",
    "Mail" : "Məktub",
    "Play" : "Oxu"
},
"nplurals=2; plural=(n != 1);");
